dollarsign: Get data from column of horizon or site data in a...

$R Documentation

Get data from column of horizon or site data in a SoilProfileCollection

Description

Get the data from a column accessed by name x$name. Column names other than profile ID are not shared between site and horizons. Accessing the profile ID column (idname(x)) with $ returns the horizon-level data with profile ID repeated for each horizon in a profile.

Usage

## S4 method for signature 'SoilProfileCollection'
x$name

Arguments

x

a SoilProfileCollection

name

a single column name in site or horizon table

See Also

site() horizons() idname() profile_id()

Examples


data(sp1)

depths(sp1) <- id ~ top + bottom

# get data from a column by name (prop)
sp1$prop


aqp documentation built on April 30, 2026, 9:06 a.m.