Learn R Programming

aqp (version 1.9.3)

munsell: Munsell-RGB Lookup Table for Common Soil Colors

Description

A lookup table of interpolated Munsell color chips for common soil colors.

Usage

data(munsell)

Arguments

Format

A data frame with 8825 observations on the following 6 variables.
hue
Munsell Hue, upper case
value
Munsell Value
chroma
Munsell Chroma
r
red value (0-1)
g
green value (0-1)
b
blue value (0-1)

Color chip XYZ values: http://www.cis.rit.edu/mcsl/online/munsell.php

Details

See munsell2rgb for conversion examples. Note that this table does not currently have entires for values of 2.5-- common in most soil color books. These chips should be added in the next major release of aqp.

References

http://www.brucelindbloom.com/index.html?ColorCalcHelp.html
Color conversion equations

http://casoilresource.lawr.ucdavis.edu/drupal/node/201
Methods used to generate this table

Examples

Run this code
data(munsell)

Run the code above in your browser using DataLab