parseMunsell: Parse Munsell Color Notation

View source: R/parseMunsell.R

parseMunsellR Documentation

Parse Munsell Color Notation

Description

Split Munsell color notation into "hue", "value", and "chroma", with optional conversion to sRGB hex notation, sRGB coordinates, and CIELAB coordinates. Conversion is performed by munsell2rgb().

Usage

parseMunsell(munsellColor, convertColors = TRUE, delim = NA, ...)

Arguments

munsellColor

character vector of Munsell colors (e.g. c('10YR 3/4', '5YR 4/6'))

convertColors

logical, convert colors to sRGB hex notation, sRGB coordinates, CIELAB coordinates

delim

optional, specify the type of delimiter used between value and chroma parts of the Munsell code. By default ":", ",:, "'", and "/" are supported.

...

additional arguments to munsell2rgb()

Value

a data.frame object

Note

This function should be able to parse and convert 100k Munsell colors in 0.5 seconds (single-threaded, 2.5GHz i7).

Author(s)

P. Roudier and D.E. Beaudette

Examples


# just sRGB
parseMunsell("10YR 3/5", return_triplets = TRUE)

# sRGB + CIELAB (D65 illuminant)
parseMunsell("10YR 3/5", return_triplets = TRUE, returnLAB = TRUE)

# CIELAB only
parseMunsell("10YR 3/5", return_triplets = FALSE, returnLAB = TRUE)

# neutral hue
# note chroma encoded as '0'
parseMunsell('N 3/', convertColors = FALSE)


aqp documentation built on April 30, 2026, 9:06 a.m.