| $ | R Documentation |
Get the data from a column accessed by name x$name. Column
names other than profile ID are not shared between site and horizons.
Accessing the profile ID column (idname(x)) with $ returns the
horizon-level data with profile ID repeated for each horizon in a profile.
## S4 method for signature 'SoilProfileCollection'
x$name
x |
a SoilProfileCollection |
name |
a single column name in site or horizon table |
site() horizons() idname() profile_id()
data(sp1)
depths(sp1) <- id ~ top + bottom
# get data from a column by name (prop)
sp1$prop
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.