| subApply | R Documentation |
subApply() is a function used for subsetting SoilProfileCollections. It currently does NOT support for "tidy" lexical features in the ... arguments passed to profileApply(). The expectation is that the function .fun takes a single-profile SoilProfileCollection and returns a logical value of length one. The use case would be for any logical comparisons that cannot be evaluated inline by subSPC() because they require more than simple logical operations.
## S4 method for signature 'SoilProfileCollection'
subApply(object, .fun, ...)
object |
A SoilProfileCollection |
.fun |
A function that takes a single profile, returns logical of length 1. |
... |
Additional arguments are passed to |
A SoilProfileCollection.
Andrew G. Brown.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.